REM Building Multi-Layer Macedonia map for Garmin devices
REM -
REM Tools needed: 
REM mkgmap (version >= 1133, http://www.mkgmap.org.uk/snapshots/mkgmap-latest.tar.gz)
REM srtm2osm (http://bodo-m.de/Srtm2Osm/Srtm2Osm-1.6.1328.1.zip)
REM - This vesion is mentioned in this OSM forum thread - http://forum.openstreetmap.org/viewtopic.php?pid=29826
REM gmt (http://www.anpo.republika.pl/files/wgmaptool044.zip)
REM wget (http://downloads.sourceforge.net/gnuwin32/wget-1.11.4-1-bin.zip)
REM gzip (http://gnuwin32.sourceforge.net/downlinks/gzip-bin-zip.php)
REM ---
REM Script should be executed in mkgmap folder (where you extracted mkgmap). 
REM Unpack srtm2osm in Srtm2Osm folder under mkgmap
REM Put other executables in path or in the mkgmap folder
REM ---

REM Fetch fresh OSM Data via OSM Server Side Scripts
wget -O OSM_MKD.osm.gz --post-file=mk_get.xml http://78.46.81.38/api/interpreter 
gzip -d -f OSM_MKD.osm.gz

REM Converting to garming img files

REM Route Layer
java -Xmx1024m -ea -jar mkgmap.jar -n 62233801 --family-id=801 --product-id=1 --series-name="OSM MK ROUTE" --family-name="OSM_MKD_ROUTE" --overview-mapname=40000801 --country-name=MACEDONIA --country-abbr=MKD --tdbfile --description="OSM_MKD_ROUTE" --code-page=1250 --name-tag-list="name:en,int_name,name:mk,name" --tdbfile --style-file="Style" --style=route --route --net --remove-short-arcs=5.5 --draw-priority=1 --road-name-pois --add-pois-to-areas --no-poi-address OSM_MKD.osm 

REM Base Layer
java -Xmx1024m -ea -jar mkgmap.jar -n 62233805 --family-id=805 --product-id=1 --series-name="OSM MK L0" --family-name="OSM_MKD_L0" --overview-mapname=40000805 --country-name=MACEDONIA --country-abbr=MKD --tdbfile --description="OSM_MKD_L0" --code-page=1252 --tdbfile --style-file="Style" --style=level0 --draw-priority=5 OSM_MKD.osm

REM Tunnel + tunnel arrows
java -Xmx1024m -ea -jar mkgmap.jar -n 62233810 --family-id=810 --product-id=1 --series-name="OSM MK TUNNEL" --family-name="OSM_MKD_TUNNEL" --overview-mapname=40000810 --country-name=MACEDONIA --country-abbr=MKD --tdbfile --description="OSM_MKD_TUNNEL" --code-page=1252 --tdbfile --style-file="Style" --style=tunnel --transparent --draw-priority=10 OSM_MKD.osm
java -Xmx1024m -ea -jar mkgmap.jar -n 62233811 --family-id=811 --product-id=1 --series-name="OSM MK TUN_AR" --family-name="OSM_MKD_TUN_AR" --overview-mapname=40000811 --country-name=MACEDONIA --country-abbr=MKD --tdbfile --description="OSM_MKD_TUN_AR" --code-page=1252 --tdbfile --style-file="Style" --style=tun_ar --transparent --draw-priority=11 OSM_MKD.osm

REM Call SRTM layer script is done in another script 
REM This is commented out as it only needs to be done once. Topogrphics feature normaly do not change 
cmd /c make_mk_srtm.cmd

REM Layer2 main roads/buildings/areas + arrows
java -Xmx1024m -ea -jar mkgmap.jar -n 62233820 --family-id=820 --product-id=1 --series-name="OSM MK L2" --family-name="OSM_MKD_L2" --overview-mapname=40000820 --country-name=MACEDONIA --country-abbr=MKD --tdbfile --description="OSM_MKD_L2" --code-page=1251 --tdbfile --style-file="Style" --style=level2 --transparent --draw-priority=20 OSM_MKD.osm
java -Xmx1024m -ea -jar mkgmap.jar -n 62233821 --family-id=821 --product-id=1 --series-name="OSM MK L2_AR" --family-name="OSM_MKD_L2_AR" --overview-mapname=40000821 --country-name=MACEDONIA --country-abbr=MKD --tdbfile --description="OSM_MKD_L2_AR" --code-page=1251 --style-file="Style" --style=l2_ar --transparent --draw-priority=21 OSM_MKD.osm

REM Bridges + arrows on top of bridges
java -Xmx1024m -ea -jar mkgmap.jar -n 62233825 --family-id=825 --product-id=1 --series-name="OSM MK BRIDGE" --family-name="OSM_MKD_BRIDGE" --overview-mapname=40000825 --country-name=MACEDONIA --country-abbr=MKD --tdbfile --description="OSM_MKD_BRIDGE" --code-page=1251 --style-file="Style" --style=bridge --transparent --draw-priority=25 OSM_MKD.osm
java -Xmx1024m -ea -jar mkgmap.jar -n 62233826 --family-id=826 --product-id=1 --series-name="OSM MK BR_AR" --family-name="OSM_MKD_BR_AR" --overview-mapname=40000826 --country-name=MACEDONIA --country-abbr=MKD --tdbfile --description="OSM_MKD_BR_AR" --code-page=1251 --style-file="Style" --style=br_ar --transparent --draw-priority=26 OSM_MKD.osm

REM Fix Family/Product ID in TYP files and package building img files

copy TYP\IK-L2v3.typ osmmk801.typ
gmt -w -y 801,1,1250 osmmk801.typ
gmt -w -y 801,1,1250 -e 62233801 62233801.img
gmt -j -f 801,1 -m "OSM MK ROUTE" -o MKROUTE.img 62233801.img osmmk801.typ
gmt -i MKROUTE.img

copy TYP\IK-L2v3.typ osmmk805.typ
gmt -w -y 805,1,1252 osmmk805.typ
gmt -w -y 805,1,1252 -e 62233805 62233805.img
gmt -j -f 805,1 -m "OSM MK BASE" -o MKBASE.img 62233805.img osmmk805.typ
gmt -i MKBASE.img

copy TYP\IK-TUN1.typ osmmk810.typ
gmt -w -y 810,1,1252 osmmk810.typ
gmt -w -y 810,1,1252 -e 62233810 62233810.img
gmt -j -f 810,1 -m "OSM MK TUNNEL" -o MKTUNNEL.img 62233810.img osmmk810.typ
gmt -i MKTUNNEL.img
copy TYP\IK-ARv2.typ osmmk811.typ
gmt -w -y 811,1,1252 osmmk811.typ
gmt -w -y 811,1,1252 -e 62233811 62233811.img
gmt -j -f 811,1 -m "OSM MK TUN_AR" -o MKTUN_AR.img 62233811.img osmmk811.typ
gmt -i MKTUN_AR.img

copy TYP\IK-L2v3.typ osmmk815.typ
gmt -w -y 815,1,1250 osmmk815.typ
gmt -j -f 815,1 -m "OSM MK SRTM" -o MKSRTM.img 6223390*.img osmmk815.typ
gmt -i MKSRTM.img

copy TYP\IK-L2v3.typ osmmk820.typ
gmt -w -y 820,1,1252 osmmk820.typ
gmt -w -y 820,1,1252 -e 62233820 62233820.img
gmt -j -f 820,1 -m "OSM MK L2" -o MKL2.img 62233820.img osmmk820.typ
gmt -i MKL2.img
copy TYP\IK-ARv2.typ osmmk821.typ
gmt -w -y 821,1,1252 osmmk821.typ
gmt -w -y 821,1,1252 -e 62233821 62233821.img
gmt -j -f 821,1 -m "OSM MK L2_AR" -o MKL2_AR.img 62233821.img osmmk821.typ
gmt -i MKL2_AR.img

copy TYP\IK-BR3.typ osmmk825.typ
gmt -w -y 825,1,1252 osmmk825.typ
gmt -w -y 825,1,1252 -e 62233825 62233825.img
gmt -j -f 825,1 -m "OSM MK BRIDGE" -o MKBRIDGE.img 62233825.img osmmk825.typ
gmt -i MKBRIDGE.img
copy TYP\IK-ARv2.typ osmmk826.typ
gmt -w -y 826,1,1252 osmmk826.typ
gmt -w -y 826,1,1252 -e 62233826 62233826.img
gmt -j -f 826,1 -m "OSM MK BR_AR" -o MKBR_AR.img 62233826.img osmmk826.typ
gmt -i MKBR_AR.img

REM Package everything into gmapsupp.img

gmt -j -o gmapsupp.img -m OSM_MK mkroute.img mkbase.img mktunnel.img mktun_ar.img mksrtm.img mkl2.img mkl2_ar.img mkbridge.img mkbr_ar.img
gmt -i gmapsupp.img

REM Done
Pause